@@ -60,18 +60,15 @@ theme_map = {
     Comment: 'comment',
     String: 'string',
     Literal: 'string',
-    Literal.String: 'string',
     Error: 'error',
     Number: 'number',
     Token.Literal.Number.Float: 'number',
     Operator: 'operator',
-    Operator.Word: 'operator',
     Punctuation: 'punctuation',
     Token: 'token',
     Whitespace: 'background',
-    Parenthesis: 'punctuation',
-    Parenthesis.UnderCursor: 'operator'
-}
+    Parenthesis: 'paren',
+    Parenthesis.UnderCursor: 'operator'}
 
 
 class BPythonFormatter(Formatter):
@@ -106,7 +103,7 @@ class BPythonFormatter(Formatter):
 
             while token not in self.f_strings:
                 token = token.parent
-            o +=  "%s\x03%s\x04" % (self.f_strings[token], text)
+            o += "%s\x03%s\x04" % (self.f_strings[token], text)
         outfile.write(o.rstrip())
 
 # vim: sw=4 ts=4 sts=4 ai et
