@@ -41,6 +41,7 @@ if not py3:
 class AttrCleaner(object):
     """A context manager that tries to make an object not exhibit side-effects
        on attribute lookup."""
+
     def __init__(self, obj):
         self.obj = obj
 
@@ -63,7 +64,7 @@ class AttrCleaner(object):
             __getattr__ = getattr(type_, '__getattr__', None)
             if __getattr__ is not None:
                 try:
-                    setattr(type_, '__getattr__', (lambda _: None))
+                    setattr(type_, '__getattr__', (lambda *_, **__: None))
                 except TypeError:
                     __getattr__ = None
             __getattribute__ = getattr(type_, '__getattribute__', None)
@@ -128,6 +129,7 @@ def parsekeywordpairs(signature):
             d[item[0]] = ''.join(item[2:])
     return d
 
+
 def fixlongargs(f, argspec):
     """Functions taking default arguments that are references to other objects
     whose str() is too big will cause breakage, so we swap out the object
